@@ -11,12 +11,20 @@ from stream_inflate import stream_inflate64
 
 
 def stream_unzip(zipfile_chunks, password=None, chunk_size=65536):
-    local_file_header_signature = b'\x50\x4b\x03\x04'
+    local_file_header_signature = b'PK\x03\x04'
     local_file_header_struct = Struct('<H2sHHHIIIHH')
     zip64_compressed_size = 0xFFFFFFFF
     zip64_size_signature = b'\x01\x00'
     aes_extra_signature = b'\x01\x99'
-    central_directory_signature = b'\x50\x4b\x01\x02'
+    central_directory_signature = b'PK\x01\x02'
+    unsigned_short = Struct('<H')
+    unsigned_long_long = Struct('<Q')
+
+    dd_optional_signature = b'PK\x07\x08'
+    dd_struct_32 = Struct('<0sIII')
+    dd_struct_32_with_sig = Struct('<4sIII')
+    dd_struct_64 = Struct('<0sIQQ')
+    dd_struct_64_with_sig = Struct('<4sIQQ')
 
     def next_or_truncated_error(it):
         try:
@@ -29,6 +37,7 @@ def stream_unzip(zipfile_chunks, password=None, chunk_size=65536):
         # - _yield_all: yields chunks as they come up (often for a "body")
         # - _get_num: returns a single `bytes` of a given length
         # - _return_unused: puts "unused" bytes "back", to be retrieved by a yield/get call
+        # - _get_offset_from_start: get the zero-indexed offset from the start of the stream
 
         chunk = b''
         offset = 0
@@ -143,7 +152,7 @@ def stream_unzip(zipfile_chunks, password=None, chunk_size=65536):
             while extra_offset <= len(extra) - 4:
                 extra_signature = extra[extra_offset:extra_offset+2]
                 extra_offset += 2
-                extra_data_size, = Struct('<H').unpack(extra[extra_offset:extra_offset+2])
+                extra_data_size, = unsigned_short.unpack(extra[extra_offset:extra_offset+2])
                 extra_offset += 2
                 extra_data = extra[extra_offset:extra_offset+extra_data_size]
                 extra_offset += extra_data_size
@@ -292,11 +301,11 @@ def stream_unzip(zipfile_chunks, password=None, chunk_size=65536):
             dd = b''
 
             checks = ((
-                (Struct('<0sIII'), b''),
-                (Struct('<4sIII'), b'PK\x07\x08'),
+                (dd_struct_32, b''),
+                (dd_struct_32_with_sig, dd_optional_signature),
             ) if not must_treat_as_zip64 else ()) + (
-                (Struct('<0sIQQ'), b''),
-                (Struct('<4sIQQ'), b'PK\x07\x08'),
+                (dd_struct_64, b''),
+                (dd_struct_64_with_sig, dd_optional_signature),
             )
 
             for dd_struct, expected_signature in checks:
@@ -305,7 +314,12 @@ def stream_unzip(zipfile_chunks, password=None, chunk_size=65536):
 
                 dd += get_num(max(dd_struct.size - len(dd), 0))
                 signature_dd, crc_32_dd, compressed_size_dd, uncompressed_size_dd = dd_struct.unpack(dd)
-                matches = (signature_dd == expected_signature, is_aes_2_encrypted or crc_32_dd == crc_32_data, compressed_size_dd == compressed_size_data, uncompressed_size_dd == uncompressed_size_data)
+                matches = (
+                    signature_dd == expected_signature,
+                    is_aes_2_encrypted or crc_32_dd == crc_32_data,
+                    compressed_size_dd == compressed_size_data,
+                    uncompressed_size_dd == uncompressed_size_data,
+                )
                 best_matches = max(best_matches, matches, key=lambda t: t.count(True))
 
             if not best_matches[0]:
@@ -347,7 +361,7 @@ def stream_unzip(zipfile_chunks, password=None, chunk_size=65536):
             raise MissingAESPasswordError()
 
         compression = \
-            Struct('<H').unpack(aes_extra[5:7])[0] if is_aes_encrypted else \
+            unsigned_short.unpack(aes_extra[5:7])[0] if is_aes_encrypted else \
             compression_raw
 
         if compression not in (0, 8, 9):
@@ -359,12 +373,12 @@ def stream_unzip(zipfile_chunks, password=None, chunk_size=65536):
 
         compressed_size = \
             None if has_data_descriptor and compression in (8, 9) else \
-            Struct('<Q').unpack(zip64_extra[8:16])[0] if is_sure_zip64 else \
+            unsigned_long_long.unpack(zip64_extra[8:16])[0] if is_sure_zip64 else \
             compressed_size_raw
 
         uncompressed_size = \
             None if has_data_descriptor and compression in (8, 9) else \
-            Struct('<Q').unpack(zip64_extra[:8])[0] if is_sure_zip64 else \
+            unsigned_long_long.unpack(zip64_extra[:8])[0] if is_sure_zip64 else \
             uncompressed_size_raw
 
         decompressor = \
